# bdl_client.ObjectBrowserPublicApiControllerApi

All URIs are relative to *https://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**append**](ObjectBrowserPublicApiControllerApi.md#append) | **POST** /api/v1/datamanagement/obj/append/b/{bucketName} | Appends a small amount of text content to the end of a file.
[**compose**](ObjectBrowserPublicApiControllerApi.md#compose) | **POST** /api/v1/datamanagement/obj/composeFrom/b/{sourceBucketName}/to/b/{destinationBucketName} | Copy all files in a directory to one output file (merge).
[**copy**](ObjectBrowserPublicApiControllerApi.md#copy) | **POST** /api/v1/datamanagement/obj/copyFrom/b/{sourceBucketName}/to/b/{destinationBucketName} | Copy files between FileSystems.
[**create**](ObjectBrowserPublicApiControllerApi.md#create) | **POST** /api/v1/datamanagement/obj/create/b/{bucketName} | Create a file or directory with default permissions and parameters.
[**delete**](ObjectBrowserPublicApiControllerApi.md#delete) | **DELETE** /api/v1/datamanagement/obj/delete/b/{bucketName} | Deletes the object at the given path from the bucket.
[**download**](ObjectBrowserPublicApiControllerApi.md#download) | **GET** /api/v1/datamanagement/obj/download/b/{bucketName} | Downloads file from the given absolute path.
[**get_description**](ObjectBrowserPublicApiControllerApi.md#get_description) | **GET** /api/v1/datamanagement/obj/description/b/{bucketName} | Return the description for the object at the specified path.
[**info**](ObjectBrowserPublicApiControllerApi.md#info) | **GET** /api/v1/datamanagement/obj/info/b/{bucketName} | Returns a FileStatus object that represents the path with information about it.
[**list**](ObjectBrowserPublicApiControllerApi.md#list) | **GET** /api/v1/datamanagement/obj/list/b/{bucketName} | List the paths of the files in the given path.
[**list_status**](ObjectBrowserPublicApiControllerApi.md#list_status) | **GET** /api/v1/datamanagement/obj/listStatus/b/{bucketName} | List the statuses and block locations of the files in the given path.
[**move**](ObjectBrowserPublicApiControllerApi.md#move) | **POST** /api/v1/datamanagement/obj/move/b/{bucketName} | Renames source object to destination object. It moves an object from source to destination path using the same file system in the same bucket.
[**set_description**](ObjectBrowserPublicApiControllerApi.md#set_description) | **POST** /api/v1/datamanagement/obj/description/b/{bucketName} | Sets the description for the object at the specified path.
[**upload**](ObjectBrowserPublicApiControllerApi.md#upload) | **POST** /api/v1/datamanagement/obj/upload/b/{bucketName} | Uploads a single file from local filesystem to given path in a bucket.


# **append**
> FileStatus append(authorization, append_form, bucket_name)

Appends a small amount of text content to the end of a file.

### Example
```python
from __future__ import print_function
import time
import bdl_client
from bdl_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = bdl_client.ObjectBrowserPublicApiControllerApi()
authorization = 'authorization_example' # str | Authorization
append_form = bdl_client.AppendForm() # AppendForm | appendForm
bucket_name = 'bucket_name_example' # str | bucketName

try:
    # Appends a small amount of text content to the end of a file.
    api_response = api_instance.append(authorization, append_form, bucket_name)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ObjectBrowserPublicApiControllerApi->append: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **str**| Authorization | 
 **append_form** | [**AppendForm**](AppendForm.md)| appendForm | 
 **bucket_name** | **str**| bucketName | 

### Return type

[**FileStatus**](FileStatus.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: */*

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **compose**
> FileStatus compose(authorization, compose_form, destination_bucket_name, source_bucket_name)

Copy all files in a directory to one output file (merge).

### Example
```python
from __future__ import print_function
import time
import bdl_client
from bdl_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = bdl_client.ObjectBrowserPublicApiControllerApi()
authorization = 'authorization_example' # str | Authorization
compose_form = bdl_client.ComposeForm() # ComposeForm | composeForm
destination_bucket_name = 'destination_bucket_name_example' # str | destinationBucketName
source_bucket_name = 'source_bucket_name_example' # str | sourceBucketName

try:
    # Copy all files in a directory to one output file (merge).
    api_response = api_instance.compose(authorization, compose_form, destination_bucket_name, source_bucket_name)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ObjectBrowserPublicApiControllerApi->compose: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **str**| Authorization | 
 **compose_form** | [**ComposeForm**](ComposeForm.md)| composeForm | 
 **destination_bucket_name** | **str**| destinationBucketName | 
 **source_bucket_name** | **str**| sourceBucketName | 

### Return type

[**FileStatus**](FileStatus.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: */*

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **copy**
> FileStatus copy(authorization, copy_form, destination_bucket_name, source_bucket_name)

Copy files between FileSystems.

### Example
```python
from __future__ import print_function
import time
import bdl_client
from bdl_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = bdl_client.ObjectBrowserPublicApiControllerApi()
authorization = 'authorization_example' # str | Authorization
copy_form = bdl_client.CopyForm() # CopyForm | copyForm
destination_bucket_name = 'destination_bucket_name_example' # str | destinationBucketName
source_bucket_name = 'source_bucket_name_example' # str | sourceBucketName

try:
    # Copy files between FileSystems.
    api_response = api_instance.copy(authorization, copy_form, destination_bucket_name, source_bucket_name)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ObjectBrowserPublicApiControllerApi->copy: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **str**| Authorization | 
 **copy_form** | [**CopyForm**](CopyForm.md)| copyForm | 
 **destination_bucket_name** | **str**| destinationBucketName | 
 **source_bucket_name** | **str**| sourceBucketName | 

### Return type

[**FileStatus**](FileStatus.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: */*

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **create**
> FileStatus create(authorization, bucket_name, create_form)

Create a file or directory with default permissions and parameters.

### Example
```python
from __future__ import print_function
import time
import bdl_client
from bdl_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = bdl_client.ObjectBrowserPublicApiControllerApi()
authorization = 'authorization_example' # str | Authorization
bucket_name = 'bucket_name_example' # str | bucketName
create_form = bdl_client.CreateForm() # CreateForm | createForm

try:
    # Create a file or directory with default permissions and parameters.
    api_response = api_instance.create(authorization, bucket_name, create_form)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ObjectBrowserPublicApiControllerApi->create: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **str**| Authorization | 
 **bucket_name** | **str**| bucketName | 
 **create_form** | [**CreateForm**](CreateForm.md)| createForm | 

### Return type

[**FileStatus**](FileStatus.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: */*

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete**
> bool delete(authorization, bucket_name, delete_form)

Deletes the object at the given path from the bucket.

### Example
```python
from __future__ import print_function
import time
import bdl_client
from bdl_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = bdl_client.ObjectBrowserPublicApiControllerApi()
authorization = 'authorization_example' # str | Authorization
bucket_name = 'bucket_name_example' # str | bucketName
delete_form = bdl_client.DeleteForm() # DeleteForm | deleteForm

try:
    # Deletes the object at the given path from the bucket.
    api_response = api_instance.delete(authorization, bucket_name, delete_form)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ObjectBrowserPublicApiControllerApi->delete: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **str**| Authorization | 
 **bucket_name** | **str**| bucketName | 
 **delete_form** | [**DeleteForm**](DeleteForm.md)| deleteForm | 

### Return type

**bool**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **download**
> download(authorization, bucket_name, object_path)

Downloads file from the given absolute path.

### Example
```python
from __future__ import print_function
import time
import bdl_client
from bdl_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = bdl_client.ObjectBrowserPublicApiControllerApi()
authorization = 'authorization_example' # str | Authorization
bucket_name = 'bucket_name_example' # str | bucketName
object_path = 'object_path_example' # str | objectPath

try:
    # Downloads file from the given absolute path.
    api_instance.download(authorization, bucket_name, object_path)
except ApiException as e:
    print("Exception when calling ObjectBrowserPublicApiControllerApi->download: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **str**| Authorization | 
 **bucket_name** | **str**| bucketName | 
 **object_path** | **str**| objectPath | 

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_description**
> str get_description(authorization, bucket_name, object_path)

Return the description for the object at the specified path.

### Example
```python
from __future__ import print_function
import time
import bdl_client
from bdl_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = bdl_client.ObjectBrowserPublicApiControllerApi()
authorization = 'authorization_example' # str | Authorization
bucket_name = 'bucket_name_example' # str | bucketName
object_path = 'object_path_example' # str | objectPath

try:
    # Return the description for the object at the specified path.
    api_response = api_instance.get_description(authorization, bucket_name, object_path)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ObjectBrowserPublicApiControllerApi->get_description: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **str**| Authorization | 
 **bucket_name** | **str**| bucketName | 
 **object_path** | **str**| objectPath | 

### Return type

**str**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **info**
> FileStatus info(authorization, bucket_name, object_path)

Returns a FileStatus object that represents the path with information about it.

### Example
```python
from __future__ import print_function
import time
import bdl_client
from bdl_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = bdl_client.ObjectBrowserPublicApiControllerApi()
authorization = 'authorization_example' # str | Authorization
bucket_name = 'bucket_name_example' # str | bucketName
object_path = 'object_path_example' # str | objectPath

try:
    # Returns a FileStatus object that represents the path with information about it.
    api_response = api_instance.info(authorization, bucket_name, object_path)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ObjectBrowserPublicApiControllerApi->info: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **str**| Authorization | 
 **bucket_name** | **str**| bucketName | 
 **object_path** | **str**| objectPath | 

### Return type

[**FileStatus**](FileStatus.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **list**
> list[str] list(authorization, bucket_name, object_path, recursive)

List the paths of the files in the given path.

### Example
```python
from __future__ import print_function
import time
import bdl_client
from bdl_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = bdl_client.ObjectBrowserPublicApiControllerApi()
authorization = 'authorization_example' # str | Authorization
bucket_name = 'bucket_name_example' # str | bucketName
object_path = 'object_path_example' # str | objectPath
recursive = true # bool | recursive

try:
    # List the paths of the files in the given path.
    api_response = api_instance.list(authorization, bucket_name, object_path, recursive)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ObjectBrowserPublicApiControllerApi->list: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **str**| Authorization | 
 **bucket_name** | **str**| bucketName | 
 **object_path** | **str**| objectPath | 
 **recursive** | **bool**| recursive | 

### Return type

**list[str]**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **list_status**
> list[FileStatus] list_status(authorization, bucket_name, object_path, recursive)

List the statuses and block locations of the files in the given path.

### Example
```python
from __future__ import print_function
import time
import bdl_client
from bdl_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = bdl_client.ObjectBrowserPublicApiControllerApi()
authorization = 'authorization_example' # str | Authorization
bucket_name = 'bucket_name_example' # str | bucketName
object_path = 'object_path_example' # str | objectPath
recursive = true # bool | recursive

try:
    # List the statuses and block locations of the files in the given path.
    api_response = api_instance.list_status(authorization, bucket_name, object_path, recursive)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ObjectBrowserPublicApiControllerApi->list_status: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **str**| Authorization | 
 **bucket_name** | **str**| bucketName | 
 **object_path** | **str**| objectPath | 
 **recursive** | **bool**| recursive | 

### Return type

[**list[FileStatus]**](FileStatus.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **move**
> FileStatus move(authorization, bucket_name, move_form)

Renames source object to destination object. It moves an object from source to destination path using the same file system in the same bucket.

### Example
```python
from __future__ import print_function
import time
import bdl_client
from bdl_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = bdl_client.ObjectBrowserPublicApiControllerApi()
authorization = 'authorization_example' # str | Authorization
bucket_name = 'bucket_name_example' # str | bucketName
move_form = bdl_client.MoveForm() # MoveForm | moveForm

try:
    # Renames source object to destination object. It moves an object from source to destination path using the same file system in the same bucket.
    api_response = api_instance.move(authorization, bucket_name, move_form)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ObjectBrowserPublicApiControllerApi->move: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **str**| Authorization | 
 **bucket_name** | **str**| bucketName | 
 **move_form** | [**MoveForm**](MoveForm.md)| moveForm | 

### Return type

[**FileStatus**](FileStatus.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: */*

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **set_description**
> bool set_description(authorization, bucket_name, description_form)

Sets the description for the object at the specified path.

### Example
```python
from __future__ import print_function
import time
import bdl_client
from bdl_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = bdl_client.ObjectBrowserPublicApiControllerApi()
authorization = 'authorization_example' # str | Authorization
bucket_name = 'bucket_name_example' # str | bucketName
description_form = bdl_client.DescriptionForm() # DescriptionForm | descriptionForm

try:
    # Sets the description for the object at the specified path.
    api_response = api_instance.set_description(authorization, bucket_name, description_form)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ObjectBrowserPublicApiControllerApi->set_description: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **str**| Authorization | 
 **bucket_name** | **str**| bucketName | 
 **description_form** | [**DescriptionForm**](DescriptionForm.md)| descriptionForm | 

### Return type

**bool**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: */*

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **upload**
> FileStatus upload(authorization, bucket_name, local_file, object_path, request_headers_e_tag=request_headers_e_tag, request_headers_accept_charset_0_registered=request_headers_accept_charset_0_registered, request_headers_accept_language_as_locales_0_iso3_country=request_headers_accept_language_as_locales_0_iso3_country, request_headers_accept_language_as_locales_0_iso3_language=request_headers_accept_language_as_locales_0_iso3_language, request_headers_accept_language_as_locales_0_country=request_headers_accept_language_as_locales_0_country, request_headers_accept_language_as_locales_0_display_country=request_headers_accept_language_as_locales_0_display_country, request_headers_accept_language_as_locales_0_display_language=request_headers_accept_language_as_locales_0_display_language, request_headers_accept_language_as_locales_0_display_name=request_headers_accept_language_as_locales_0_display_name, request_headers_accept_language_as_locales_0_display_script=request_headers_accept_language_as_locales_0_display_script, request_headers_accept_language_as_locales_0_display_variant=request_headers_accept_language_as_locales_0_display_variant, request_headers_accept_language_as_locales_0_language=request_headers_accept_language_as_locales_0_language, request_headers_accept_language_as_locales_0_script=request_headers_accept_language_as_locales_0_script, request_headers_accept_language_as_locales_0_unicode_locale_attributes=request_headers_accept_language_as_locales_0_unicode_locale_attributes, request_headers_accept_language_as_locales_0_unicode_locale_keys=request_headers_accept_language_as_locales_0_unicode_locale_keys, request_headers_accept_language_as_locales_0_variant=request_headers_accept_language_as_locales_0_variant, request_headers_accept_language_0_range=request_headers_accept_language_0_range, request_headers_accept_language_0_weight=request_headers_accept_language_0_weight, request_headers_accept_0_charset_registered=request_headers_accept_0_charset_registered, request_headers_accept_0_concrete=request_headers_accept_0_concrete, request_headers_accept_0_quality_value=request_headers_accept_0_quality_value, request_headers_accept_0_subtype=request_headers_accept_0_subtype, request_headers_accept_0_type=request_headers_accept_0_type, request_headers_accept_0_wildcard_subtype=request_headers_accept_0_wildcard_subtype, request_headers_accept_0_wildcard_type=request_headers_accept_0_wildcard_type, request_headers_access_control_allow_credentials=request_headers_access_control_allow_credentials, request_headers_access_control_allow_headers=request_headers_access_control_allow_headers, request_headers_access_control_allow_methods=request_headers_access_control_allow_methods, request_headers_access_control_allow_origin=request_headers_access_control_allow_origin, request_headers_access_control_expose_headers=request_headers_access_control_expose_headers, request_headers_access_control_max_age=request_headers_access_control_max_age, request_headers_access_control_request_headers=request_headers_access_control_request_headers, request_headers_access_control_request_method=request_headers_access_control_request_method, request_headers_allow=request_headers_allow, request_headers_cache_control=request_headers_cache_control, request_headers_connection=request_headers_connection, request_headers_content_disposition_charset_registered=request_headers_content_disposition_charset_registered, request_headers_content_disposition_creation_date=request_headers_content_disposition_creation_date, request_headers_content_disposition_filename=request_headers_content_disposition_filename, request_headers_content_disposition_modification_date=request_headers_content_disposition_modification_date, request_headers_content_disposition_name=request_headers_content_disposition_name, request_headers_content_disposition_read_date=request_headers_content_disposition_read_date, request_headers_content_disposition_size=request_headers_content_disposition_size, request_headers_content_disposition_type=request_headers_content_disposition_type, request_headers_content_language_iso3_country=request_headers_content_language_iso3_country, request_headers_content_language_iso3_language=request_headers_content_language_iso3_language, request_headers_content_language_country=request_headers_content_language_country, request_headers_content_language_display_country=request_headers_content_language_display_country, request_headers_content_language_display_language=request_headers_content_language_display_language, request_headers_content_language_display_name=request_headers_content_language_display_name, request_headers_content_language_display_script=request_headers_content_language_display_script, request_headers_content_language_display_variant=request_headers_content_language_display_variant, request_headers_content_language_language=request_headers_content_language_language, request_headers_content_language_script=request_headers_content_language_script, request_headers_content_language_unicode_locale_attributes=request_headers_content_language_unicode_locale_attributes, request_headers_content_language_unicode_locale_keys=request_headers_content_language_unicode_locale_keys, request_headers_content_language_variant=request_headers_content_language_variant, request_headers_content_length=request_headers_content_length, request_headers_content_type_charset_registered=request_headers_content_type_charset_registered, request_headers_content_type_concrete=request_headers_content_type_concrete, request_headers_content_type_quality_value=request_headers_content_type_quality_value, request_headers_content_type_subtype=request_headers_content_type_subtype, request_headers_content_type_type=request_headers_content_type_type, request_headers_content_type_wildcard_subtype=request_headers_content_type_wildcard_subtype, request_headers_content_type_wildcard_type=request_headers_content_type_wildcard_type, request_headers_date=request_headers_date, request_headers_expires=request_headers_expires, request_headers_host_address_mc_global=request_headers_host_address_mc_global, request_headers_host_address_mc_link_local=request_headers_host_address_mc_link_local, request_headers_host_address_mc_node_local=request_headers_host_address_mc_node_local, request_headers_host_address_mc_org_local=request_headers_host_address_mc_org_local, request_headers_host_address_mc_site_local=request_headers_host_address_mc_site_local, request_headers_host_address_address=request_headers_host_address_address, request_headers_host_address_any_local_address=request_headers_host_address_any_local_address, request_headers_host_address_canonical_host_name=request_headers_host_address_canonical_host_name, request_headers_host_address_host_address=request_headers_host_address_host_address, request_headers_host_address_host_name=request_headers_host_address_host_name, request_headers_host_address_link_local_address=request_headers_host_address_link_local_address, request_headers_host_address_loopback_address=request_headers_host_address_loopback_address, request_headers_host_address_multicast_address=request_headers_host_address_multicast_address, request_headers_host_address_site_local_address=request_headers_host_address_site_local_address, request_headers_host_host_name=request_headers_host_host_name, request_headers_host_host_string=request_headers_host_host_string, request_headers_host_port=request_headers_host_port, request_headers_host_unresolved=request_headers_host_unresolved, request_headers_if_match=request_headers_if_match, request_headers_if_modified_since=request_headers_if_modified_since, request_headers_if_none_match=request_headers_if_none_match, request_headers_if_unmodified_since=request_headers_if_unmodified_since, request_headers_last_modified=request_headers_last_modified, request_headers_location_absolute=request_headers_location_absolute, request_headers_location_authority=request_headers_location_authority, request_headers_location_fragment=request_headers_location_fragment, request_headers_location_host=request_headers_location_host, request_headers_location_opaque=request_headers_location_opaque, request_headers_location_path=request_headers_location_path, request_headers_location_port=request_headers_location_port, request_headers_location_query=request_headers_location_query, request_headers_location_raw_authority=request_headers_location_raw_authority, request_headers_location_raw_fragment=request_headers_location_raw_fragment, request_headers_location_raw_path=request_headers_location_raw_path, request_headers_location_raw_query=request_headers_location_raw_query, request_headers_location_raw_scheme_specific_part=request_headers_location_raw_scheme_specific_part, request_headers_location_raw_user_info=request_headers_location_raw_user_info, request_headers_location_scheme=request_headers_location_scheme, request_headers_location_scheme_specific_part=request_headers_location_scheme_specific_part, request_headers_location_user_info=request_headers_location_user_info, request_headers_origin=request_headers_origin, request_headers_pragma=request_headers_pragma, request_headers_upgrade=request_headers_upgrade, request_headers_vary=request_headers_vary, request_method=request_method)

Uploads a single file from local filesystem to given path in a bucket.

### Example
```python
from __future__ import print_function
import time
import bdl_client
from bdl_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = bdl_client.ObjectBrowserPublicApiControllerApi()
authorization = 'authorization_example' # str | Authorization
bucket_name = 'bucket_name_example' # str | bucketName
local_file = '/path/to/file.txt' # file | localFile
object_path = 'object_path_example' # str | objectPath
request_headers_e_tag = 'request_headers_e_tag_example' # str |  (optional)
request_headers_accept_charset_0_registered = true # bool |  (optional)
request_headers_accept_language_as_locales_0_iso3_country = 'request_headers_accept_language_as_locales_0_iso3_country_example' # str |  (optional)
request_headers_accept_language_as_locales_0_iso3_language = 'request_headers_accept_language_as_locales_0_iso3_language_example' # str |  (optional)
request_headers_accept_language_as_locales_0_country = 'request_headers_accept_language_as_locales_0_country_example' # str |  (optional)
request_headers_accept_language_as_locales_0_display_country = 'request_headers_accept_language_as_locales_0_display_country_example' # str |  (optional)
request_headers_accept_language_as_locales_0_display_language = 'request_headers_accept_language_as_locales_0_display_language_example' # str |  (optional)
request_headers_accept_language_as_locales_0_display_name = 'request_headers_accept_language_as_locales_0_display_name_example' # str |  (optional)
request_headers_accept_language_as_locales_0_display_script = 'request_headers_accept_language_as_locales_0_display_script_example' # str |  (optional)
request_headers_accept_language_as_locales_0_display_variant = 'request_headers_accept_language_as_locales_0_display_variant_example' # str |  (optional)
request_headers_accept_language_as_locales_0_language = 'request_headers_accept_language_as_locales_0_language_example' # str |  (optional)
request_headers_accept_language_as_locales_0_script = 'request_headers_accept_language_as_locales_0_script_example' # str |  (optional)
request_headers_accept_language_as_locales_0_unicode_locale_attributes = ['request_headers_accept_language_as_locales_0_unicode_locale_attributes_example'] # list[str] |  (optional)
request_headers_accept_language_as_locales_0_unicode_locale_keys = ['request_headers_accept_language_as_locales_0_unicode_locale_keys_example'] # list[str] |  (optional)
request_headers_accept_language_as_locales_0_variant = 'request_headers_accept_language_as_locales_0_variant_example' # str |  (optional)
request_headers_accept_language_0_range = 'request_headers_accept_language_0_range_example' # str |  (optional)
request_headers_accept_language_0_weight = 1.2 # float |  (optional)
request_headers_accept_0_charset_registered = true # bool |  (optional)
request_headers_accept_0_concrete = true # bool |  (optional)
request_headers_accept_0_quality_value = 1.2 # float |  (optional)
request_headers_accept_0_subtype = 'request_headers_accept_0_subtype_example' # str |  (optional)
request_headers_accept_0_type = 'request_headers_accept_0_type_example' # str |  (optional)
request_headers_accept_0_wildcard_subtype = true # bool |  (optional)
request_headers_accept_0_wildcard_type = true # bool |  (optional)
request_headers_access_control_allow_credentials = true # bool |  (optional)
request_headers_access_control_allow_headers = ['request_headers_access_control_allow_headers_example'] # list[str] |  (optional)
request_headers_access_control_allow_methods = ['request_headers_access_control_allow_methods_example'] # list[str] |  (optional)
request_headers_access_control_allow_origin = 'request_headers_access_control_allow_origin_example' # str |  (optional)
request_headers_access_control_expose_headers = ['request_headers_access_control_expose_headers_example'] # list[str] |  (optional)
request_headers_access_control_max_age = 789 # int |  (optional)
request_headers_access_control_request_headers = ['request_headers_access_control_request_headers_example'] # list[str] |  (optional)
request_headers_access_control_request_method = 'request_headers_access_control_request_method_example' # str |  (optional)
request_headers_allow = ['request_headers_allow_example'] # list[str] |  (optional)
request_headers_cache_control = 'request_headers_cache_control_example' # str |  (optional)
request_headers_connection = ['request_headers_connection_example'] # list[str] |  (optional)
request_headers_content_disposition_charset_registered = true # bool |  (optional)
request_headers_content_disposition_creation_date = '2013-10-20T19:20:30+01:00' # datetime |  (optional)
request_headers_content_disposition_filename = 'request_headers_content_disposition_filename_example' # str |  (optional)
request_headers_content_disposition_modification_date = '2013-10-20T19:20:30+01:00' # datetime |  (optional)
request_headers_content_disposition_name = 'request_headers_content_disposition_name_example' # str |  (optional)
request_headers_content_disposition_read_date = '2013-10-20T19:20:30+01:00' # datetime |  (optional)
request_headers_content_disposition_size = 789 # int |  (optional)
request_headers_content_disposition_type = 'request_headers_content_disposition_type_example' # str |  (optional)
request_headers_content_language_iso3_country = 'request_headers_content_language_iso3_country_example' # str |  (optional)
request_headers_content_language_iso3_language = 'request_headers_content_language_iso3_language_example' # str |  (optional)
request_headers_content_language_country = 'request_headers_content_language_country_example' # str |  (optional)
request_headers_content_language_display_country = 'request_headers_content_language_display_country_example' # str |  (optional)
request_headers_content_language_display_language = 'request_headers_content_language_display_language_example' # str |  (optional)
request_headers_content_language_display_name = 'request_headers_content_language_display_name_example' # str |  (optional)
request_headers_content_language_display_script = 'request_headers_content_language_display_script_example' # str |  (optional)
request_headers_content_language_display_variant = 'request_headers_content_language_display_variant_example' # str |  (optional)
request_headers_content_language_language = 'request_headers_content_language_language_example' # str |  (optional)
request_headers_content_language_script = 'request_headers_content_language_script_example' # str |  (optional)
request_headers_content_language_unicode_locale_attributes = ['request_headers_content_language_unicode_locale_attributes_example'] # list[str] |  (optional)
request_headers_content_language_unicode_locale_keys = ['request_headers_content_language_unicode_locale_keys_example'] # list[str] |  (optional)
request_headers_content_language_variant = 'request_headers_content_language_variant_example' # str |  (optional)
request_headers_content_length = 789 # int |  (optional)
request_headers_content_type_charset_registered = true # bool |  (optional)
request_headers_content_type_concrete = true # bool |  (optional)
request_headers_content_type_quality_value = 1.2 # float |  (optional)
request_headers_content_type_subtype = 'request_headers_content_type_subtype_example' # str |  (optional)
request_headers_content_type_type = 'request_headers_content_type_type_example' # str |  (optional)
request_headers_content_type_wildcard_subtype = true # bool |  (optional)
request_headers_content_type_wildcard_type = true # bool |  (optional)
request_headers_date = 789 # int |  (optional)
request_headers_expires = 789 # int |  (optional)
request_headers_host_address_mc_global = true # bool |  (optional)
request_headers_host_address_mc_link_local = true # bool |  (optional)
request_headers_host_address_mc_node_local = true # bool |  (optional)
request_headers_host_address_mc_org_local = true # bool |  (optional)
request_headers_host_address_mc_site_local = true # bool |  (optional)
request_headers_host_address_address = 'B' # str |  (optional)
request_headers_host_address_any_local_address = true # bool |  (optional)
request_headers_host_address_canonical_host_name = 'request_headers_host_address_canonical_host_name_example' # str |  (optional)
request_headers_host_address_host_address = 'request_headers_host_address_host_address_example' # str |  (optional)
request_headers_host_address_host_name = 'request_headers_host_address_host_name_example' # str |  (optional)
request_headers_host_address_link_local_address = true # bool |  (optional)
request_headers_host_address_loopback_address = true # bool |  (optional)
request_headers_host_address_multicast_address = true # bool |  (optional)
request_headers_host_address_site_local_address = true # bool |  (optional)
request_headers_host_host_name = 'request_headers_host_host_name_example' # str |  (optional)
request_headers_host_host_string = 'request_headers_host_host_string_example' # str |  (optional)
request_headers_host_port = 56 # int |  (optional)
request_headers_host_unresolved = true # bool |  (optional)
request_headers_if_match = ['request_headers_if_match_example'] # list[str] |  (optional)
request_headers_if_modified_since = 789 # int |  (optional)
request_headers_if_none_match = ['request_headers_if_none_match_example'] # list[str] |  (optional)
request_headers_if_unmodified_since = 789 # int |  (optional)
request_headers_last_modified = 789 # int |  (optional)
request_headers_location_absolute = true # bool |  (optional)
request_headers_location_authority = 'request_headers_location_authority_example' # str |  (optional)
request_headers_location_fragment = 'request_headers_location_fragment_example' # str |  (optional)
request_headers_location_host = 'request_headers_location_host_example' # str |  (optional)
request_headers_location_opaque = true # bool |  (optional)
request_headers_location_path = 'request_headers_location_path_example' # str |  (optional)
request_headers_location_port = 56 # int |  (optional)
request_headers_location_query = 'request_headers_location_query_example' # str |  (optional)
request_headers_location_raw_authority = 'request_headers_location_raw_authority_example' # str |  (optional)
request_headers_location_raw_fragment = 'request_headers_location_raw_fragment_example' # str |  (optional)
request_headers_location_raw_path = 'request_headers_location_raw_path_example' # str |  (optional)
request_headers_location_raw_query = 'request_headers_location_raw_query_example' # str |  (optional)
request_headers_location_raw_scheme_specific_part = 'request_headers_location_raw_scheme_specific_part_example' # str |  (optional)
request_headers_location_raw_user_info = 'request_headers_location_raw_user_info_example' # str |  (optional)
request_headers_location_scheme = 'request_headers_location_scheme_example' # str |  (optional)
request_headers_location_scheme_specific_part = 'request_headers_location_scheme_specific_part_example' # str |  (optional)
request_headers_location_user_info = 'request_headers_location_user_info_example' # str |  (optional)
request_headers_origin = 'request_headers_origin_example' # str |  (optional)
request_headers_pragma = 'request_headers_pragma_example' # str |  (optional)
request_headers_upgrade = 'request_headers_upgrade_example' # str |  (optional)
request_headers_vary = ['request_headers_vary_example'] # list[str] |  (optional)
request_method = 'request_method_example' # str |  (optional)

try:
    # Uploads a single file from local filesystem to given path in a bucket.
    api_response = api_instance.upload(authorization, bucket_name, local_file, object_path, request_headers_e_tag=request_headers_e_tag, request_headers_accept_charset_0_registered=request_headers_accept_charset_0_registered, request_headers_accept_language_as_locales_0_iso3_country=request_headers_accept_language_as_locales_0_iso3_country, request_headers_accept_language_as_locales_0_iso3_language=request_headers_accept_language_as_locales_0_iso3_language, request_headers_accept_language_as_locales_0_country=request_headers_accept_language_as_locales_0_country, request_headers_accept_language_as_locales_0_display_country=request_headers_accept_language_as_locales_0_display_country, request_headers_accept_language_as_locales_0_display_language=request_headers_accept_language_as_locales_0_display_language, request_headers_accept_language_as_locales_0_display_name=request_headers_accept_language_as_locales_0_display_name, request_headers_accept_language_as_locales_0_display_script=request_headers_accept_language_as_locales_0_display_script, request_headers_accept_language_as_locales_0_display_variant=request_headers_accept_language_as_locales_0_display_variant, request_headers_accept_language_as_locales_0_language=request_headers_accept_language_as_locales_0_language, request_headers_accept_language_as_locales_0_script=request_headers_accept_language_as_locales_0_script, request_headers_accept_language_as_locales_0_unicode_locale_attributes=request_headers_accept_language_as_locales_0_unicode_locale_attributes, request_headers_accept_language_as_locales_0_unicode_locale_keys=request_headers_accept_language_as_locales_0_unicode_locale_keys, request_headers_accept_language_as_locales_0_variant=request_headers_accept_language_as_locales_0_variant, request_headers_accept_language_0_range=request_headers_accept_language_0_range, request_headers_accept_language_0_weight=request_headers_accept_language_0_weight, request_headers_accept_0_charset_registered=request_headers_accept_0_charset_registered, request_headers_accept_0_concrete=request_headers_accept_0_concrete, request_headers_accept_0_quality_value=request_headers_accept_0_quality_value, request_headers_accept_0_subtype=request_headers_accept_0_subtype, request_headers_accept_0_type=request_headers_accept_0_type, request_headers_accept_0_wildcard_subtype=request_headers_accept_0_wildcard_subtype, request_headers_accept_0_wildcard_type=request_headers_accept_0_wildcard_type, request_headers_access_control_allow_credentials=request_headers_access_control_allow_credentials, request_headers_access_control_allow_headers=request_headers_access_control_allow_headers, request_headers_access_control_allow_methods=request_headers_access_control_allow_methods, request_headers_access_control_allow_origin=request_headers_access_control_allow_origin, request_headers_access_control_expose_headers=request_headers_access_control_expose_headers, request_headers_access_control_max_age=request_headers_access_control_max_age, request_headers_access_control_request_headers=request_headers_access_control_request_headers, request_headers_access_control_request_method=request_headers_access_control_request_method, request_headers_allow=request_headers_allow, request_headers_cache_control=request_headers_cache_control, request_headers_connection=request_headers_connection, request_headers_content_disposition_charset_registered=request_headers_content_disposition_charset_registered, request_headers_content_disposition_creation_date=request_headers_content_disposition_creation_date, request_headers_content_disposition_filename=request_headers_content_disposition_filename, request_headers_content_disposition_modification_date=request_headers_content_disposition_modification_date, request_headers_content_disposition_name=request_headers_content_disposition_name, request_headers_content_disposition_read_date=request_headers_content_disposition_read_date, request_headers_content_disposition_size=request_headers_content_disposition_size, request_headers_content_disposition_type=request_headers_content_disposition_type, request_headers_content_language_iso3_country=request_headers_content_language_iso3_country, request_headers_content_language_iso3_language=request_headers_content_language_iso3_language, request_headers_content_language_country=request_headers_content_language_country, request_headers_content_language_display_country=request_headers_content_language_display_country, request_headers_content_language_display_language=request_headers_content_language_display_language, request_headers_content_language_display_name=request_headers_content_language_display_name, request_headers_content_language_display_script=request_headers_content_language_display_script, request_headers_content_language_display_variant=request_headers_content_language_display_variant, request_headers_content_language_language=request_headers_content_language_language, request_headers_content_language_script=request_headers_content_language_script, request_headers_content_language_unicode_locale_attributes=request_headers_content_language_unicode_locale_attributes, request_headers_content_language_unicode_locale_keys=request_headers_content_language_unicode_locale_keys, request_headers_content_language_variant=request_headers_content_language_variant, request_headers_content_length=request_headers_content_length, request_headers_content_type_charset_registered=request_headers_content_type_charset_registered, request_headers_content_type_concrete=request_headers_content_type_concrete, request_headers_content_type_quality_value=request_headers_content_type_quality_value, request_headers_content_type_subtype=request_headers_content_type_subtype, request_headers_content_type_type=request_headers_content_type_type, request_headers_content_type_wildcard_subtype=request_headers_content_type_wildcard_subtype, request_headers_content_type_wildcard_type=request_headers_content_type_wildcard_type, request_headers_date=request_headers_date, request_headers_expires=request_headers_expires, request_headers_host_address_mc_global=request_headers_host_address_mc_global, request_headers_host_address_mc_link_local=request_headers_host_address_mc_link_local, request_headers_host_address_mc_node_local=request_headers_host_address_mc_node_local, request_headers_host_address_mc_org_local=request_headers_host_address_mc_org_local, request_headers_host_address_mc_site_local=request_headers_host_address_mc_site_local, request_headers_host_address_address=request_headers_host_address_address, request_headers_host_address_any_local_address=request_headers_host_address_any_local_address, request_headers_host_address_canonical_host_name=request_headers_host_address_canonical_host_name, request_headers_host_address_host_address=request_headers_host_address_host_address, request_headers_host_address_host_name=request_headers_host_address_host_name, request_headers_host_address_link_local_address=request_headers_host_address_link_local_address, request_headers_host_address_loopback_address=request_headers_host_address_loopback_address, request_headers_host_address_multicast_address=request_headers_host_address_multicast_address, request_headers_host_address_site_local_address=request_headers_host_address_site_local_address, request_headers_host_host_name=request_headers_host_host_name, request_headers_host_host_string=request_headers_host_host_string, request_headers_host_port=request_headers_host_port, request_headers_host_unresolved=request_headers_host_unresolved, request_headers_if_match=request_headers_if_match, request_headers_if_modified_since=request_headers_if_modified_since, request_headers_if_none_match=request_headers_if_none_match, request_headers_if_unmodified_since=request_headers_if_unmodified_since, request_headers_last_modified=request_headers_last_modified, request_headers_location_absolute=request_headers_location_absolute, request_headers_location_authority=request_headers_location_authority, request_headers_location_fragment=request_headers_location_fragment, request_headers_location_host=request_headers_location_host, request_headers_location_opaque=request_headers_location_opaque, request_headers_location_path=request_headers_location_path, request_headers_location_port=request_headers_location_port, request_headers_location_query=request_headers_location_query, request_headers_location_raw_authority=request_headers_location_raw_authority, request_headers_location_raw_fragment=request_headers_location_raw_fragment, request_headers_location_raw_path=request_headers_location_raw_path, request_headers_location_raw_query=request_headers_location_raw_query, request_headers_location_raw_scheme_specific_part=request_headers_location_raw_scheme_specific_part, request_headers_location_raw_user_info=request_headers_location_raw_user_info, request_headers_location_scheme=request_headers_location_scheme, request_headers_location_scheme_specific_part=request_headers_location_scheme_specific_part, request_headers_location_user_info=request_headers_location_user_info, request_headers_origin=request_headers_origin, request_headers_pragma=request_headers_pragma, request_headers_upgrade=request_headers_upgrade, request_headers_vary=request_headers_vary, request_method=request_method)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ObjectBrowserPublicApiControllerApi->upload: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **str**| Authorization | 
 **bucket_name** | **str**| bucketName | 
 **local_file** | **file**| localFile | 
 **object_path** | **str**| objectPath | 
 **request_headers_e_tag** | **str**|  | [optional] 
 **request_headers_accept_charset_0_registered** | **bool**|  | [optional] 
 **request_headers_accept_language_as_locales_0_iso3_country** | **str**|  | [optional] 
 **request_headers_accept_language_as_locales_0_iso3_language** | **str**|  | [optional] 
 **request_headers_accept_language_as_locales_0_country** | **str**|  | [optional] 
 **request_headers_accept_language_as_locales_0_display_country** | **str**|  | [optional] 
 **request_headers_accept_language_as_locales_0_display_language** | **str**|  | [optional] 
 **request_headers_accept_language_as_locales_0_display_name** | **str**|  | [optional] 
 **request_headers_accept_language_as_locales_0_display_script** | **str**|  | [optional] 
 **request_headers_accept_language_as_locales_0_display_variant** | **str**|  | [optional] 
 **request_headers_accept_language_as_locales_0_language** | **str**|  | [optional] 
 **request_headers_accept_language_as_locales_0_script** | **str**|  | [optional] 
 **request_headers_accept_language_as_locales_0_unicode_locale_attributes** | [**list[str]**](str.md)|  | [optional] 
 **request_headers_accept_language_as_locales_0_unicode_locale_keys** | [**list[str]**](str.md)|  | [optional] 
 **request_headers_accept_language_as_locales_0_variant** | **str**|  | [optional] 
 **request_headers_accept_language_0_range** | **str**|  | [optional] 
 **request_headers_accept_language_0_weight** | **float**|  | [optional] 
 **request_headers_accept_0_charset_registered** | **bool**|  | [optional] 
 **request_headers_accept_0_concrete** | **bool**|  | [optional] 
 **request_headers_accept_0_quality_value** | **float**|  | [optional] 
 **request_headers_accept_0_subtype** | **str**|  | [optional] 
 **request_headers_accept_0_type** | **str**|  | [optional] 
 **request_headers_accept_0_wildcard_subtype** | **bool**|  | [optional] 
 **request_headers_accept_0_wildcard_type** | **bool**|  | [optional] 
 **request_headers_access_control_allow_credentials** | **bool**|  | [optional] 
 **request_headers_access_control_allow_headers** | [**list[str]**](str.md)|  | [optional] 
 **request_headers_access_control_allow_methods** | [**list[str]**](str.md)|  | [optional] 
 **request_headers_access_control_allow_origin** | **str**|  | [optional] 
 **request_headers_access_control_expose_headers** | [**list[str]**](str.md)|  | [optional] 
 **request_headers_access_control_max_age** | **int**|  | [optional] 
 **request_headers_access_control_request_headers** | [**list[str]**](str.md)|  | [optional] 
 **request_headers_access_control_request_method** | **str**|  | [optional] 
 **request_headers_allow** | [**list[str]**](str.md)|  | [optional] 
 **request_headers_cache_control** | **str**|  | [optional] 
 **request_headers_connection** | [**list[str]**](str.md)|  | [optional] 
 **request_headers_content_disposition_charset_registered** | **bool**|  | [optional] 
 **request_headers_content_disposition_creation_date** | **datetime**|  | [optional] 
 **request_headers_content_disposition_filename** | **str**|  | [optional] 
 **request_headers_content_disposition_modification_date** | **datetime**|  | [optional] 
 **request_headers_content_disposition_name** | **str**|  | [optional] 
 **request_headers_content_disposition_read_date** | **datetime**|  | [optional] 
 **request_headers_content_disposition_size** | **int**|  | [optional] 
 **request_headers_content_disposition_type** | **str**|  | [optional] 
 **request_headers_content_language_iso3_country** | **str**|  | [optional] 
 **request_headers_content_language_iso3_language** | **str**|  | [optional] 
 **request_headers_content_language_country** | **str**|  | [optional] 
 **request_headers_content_language_display_country** | **str**|  | [optional] 
 **request_headers_content_language_display_language** | **str**|  | [optional] 
 **request_headers_content_language_display_name** | **str**|  | [optional] 
 **request_headers_content_language_display_script** | **str**|  | [optional] 
 **request_headers_content_language_display_variant** | **str**|  | [optional] 
 **request_headers_content_language_language** | **str**|  | [optional] 
 **request_headers_content_language_script** | **str**|  | [optional] 
 **request_headers_content_language_unicode_locale_attributes** | [**list[str]**](str.md)|  | [optional] 
 **request_headers_content_language_unicode_locale_keys** | [**list[str]**](str.md)|  | [optional] 
 **request_headers_content_language_variant** | **str**|  | [optional] 
 **request_headers_content_length** | **int**|  | [optional] 
 **request_headers_content_type_charset_registered** | **bool**|  | [optional] 
 **request_headers_content_type_concrete** | **bool**|  | [optional] 
 **request_headers_content_type_quality_value** | **float**|  | [optional] 
 **request_headers_content_type_subtype** | **str**|  | [optional] 
 **request_headers_content_type_type** | **str**|  | [optional] 
 **request_headers_content_type_wildcard_subtype** | **bool**|  | [optional] 
 **request_headers_content_type_wildcard_type** | **bool**|  | [optional] 
 **request_headers_date** | **int**|  | [optional] 
 **request_headers_expires** | **int**|  | [optional] 
 **request_headers_host_address_mc_global** | **bool**|  | [optional] 
 **request_headers_host_address_mc_link_local** | **bool**|  | [optional] 
 **request_headers_host_address_mc_node_local** | **bool**|  | [optional] 
 **request_headers_host_address_mc_org_local** | **bool**|  | [optional] 
 **request_headers_host_address_mc_site_local** | **bool**|  | [optional] 
 **request_headers_host_address_address** | **str**|  | [optional] 
 **request_headers_host_address_any_local_address** | **bool**|  | [optional] 
 **request_headers_host_address_canonical_host_name** | **str**|  | [optional] 
 **request_headers_host_address_host_address** | **str**|  | [optional] 
 **request_headers_host_address_host_name** | **str**|  | [optional] 
 **request_headers_host_address_link_local_address** | **bool**|  | [optional] 
 **request_headers_host_address_loopback_address** | **bool**|  | [optional] 
 **request_headers_host_address_multicast_address** | **bool**|  | [optional] 
 **request_headers_host_address_site_local_address** | **bool**|  | [optional] 
 **request_headers_host_host_name** | **str**|  | [optional] 
 **request_headers_host_host_string** | **str**|  | [optional] 
 **request_headers_host_port** | **int**|  | [optional] 
 **request_headers_host_unresolved** | **bool**|  | [optional] 
 **request_headers_if_match** | [**list[str]**](str.md)|  | [optional] 
 **request_headers_if_modified_since** | **int**|  | [optional] 
 **request_headers_if_none_match** | [**list[str]**](str.md)|  | [optional] 
 **request_headers_if_unmodified_since** | **int**|  | [optional] 
 **request_headers_last_modified** | **int**|  | [optional] 
 **request_headers_location_absolute** | **bool**|  | [optional] 
 **request_headers_location_authority** | **str**|  | [optional] 
 **request_headers_location_fragment** | **str**|  | [optional] 
 **request_headers_location_host** | **str**|  | [optional] 
 **request_headers_location_opaque** | **bool**|  | [optional] 
 **request_headers_location_path** | **str**|  | [optional] 
 **request_headers_location_port** | **int**|  | [optional] 
 **request_headers_location_query** | **str**|  | [optional] 
 **request_headers_location_raw_authority** | **str**|  | [optional] 
 **request_headers_location_raw_fragment** | **str**|  | [optional] 
 **request_headers_location_raw_path** | **str**|  | [optional] 
 **request_headers_location_raw_query** | **str**|  | [optional] 
 **request_headers_location_raw_scheme_specific_part** | **str**|  | [optional] 
 **request_headers_location_raw_user_info** | **str**|  | [optional] 
 **request_headers_location_scheme** | **str**|  | [optional] 
 **request_headers_location_scheme_specific_part** | **str**|  | [optional] 
 **request_headers_location_user_info** | **str**|  | [optional] 
 **request_headers_origin** | **str**|  | [optional] 
 **request_headers_pragma** | **str**|  | [optional] 
 **request_headers_upgrade** | **str**|  | [optional] 
 **request_headers_vary** | [**list[str]**](str.md)|  | [optional] 
 **request_method** | **str**|  | [optional] 

### Return type

[**FileStatus**](FileStatus.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: multipart/form-data
 - **Accept**: */*

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

